pub struct ExportChainSpecCmd {
pub chain: String,
pub output: Option<PathBuf>,
pub raw: bool,
}Expand description
Export a chain-spec to a JSON file in plain or in raw storage format.
Nodes that expose this command usually have embedded runtimes WASM blobs with
genesis config presets which can be referenced via --chain <id> . The logic for
loading the chain spec into memory based on an id is specific to each
node and is a prerequisite to enable this command.
Same functionality can be achieved currently via
crate::commands::build_spec_cmd::BuildSpecCmd but we recommend
export-chain-spec in its stead. build-spec is known
to be a legacy mix of exporting chain specs to JSON files or
converting them to raw, which will be better
represented under export-chain-spec.
Fields
chain: StringThe chain spec identifier to export.
output: Option<PathBuf>chain-spec JSON file path. If omitted, prints to stdout.
raw: boolExport in raw genesis storage format.
Implementations