pub struct RunCmd {Show 23 fields
pub validator: bool,
pub no_grandpa: bool,
pub name: Option<String>,
pub rpc_params: RpcParams,
pub telemetry_params: TelemetryParams,
pub prometheus_params: PrometheusParams,
pub runtime_params: RuntimeParams,
pub offchain_worker_params: OffchainWorkerParams,
pub shared_params: SharedParams,
pub import_params: ImportParams,
pub network_params: NetworkParams,
pub pool_config: TransactionPoolParams,
pub keystore_params: KeystoreParams,
pub alice: bool,
pub bob: bool,
pub charlie: bool,
pub dave: bool,
pub eve: bool,
pub ferdie: bool,
pub one: bool,
pub two: bool,
pub force_authoring: bool,
pub tmp: bool,
}Expand description
The run command used to run a node.
Fields
validator: boolEnable validator mode.
The node will be started with the authority role and actively participate in any consensus task that it can (e.g. depending on availability of local keys).
no_grandpa: boolDisable GRANDPA.
Disables voter when running in validator mode, otherwise disable the GRANDPA observer.
name: Option<String>The human-readable name for this node.
It’s used as network node name.
rpc_params: RpcParamstelemetry_params: TelemetryParamsprometheus_params: PrometheusParamsruntime_params: RuntimeParamsoffchain_worker_params: OffchainWorkerParamsimport_params: ImportParamsnetwork_params: NetworkParamspool_config: TransactionPoolParamskeystore_params: KeystoreParamsalice: boolShortcut for --name Alice --validator.
Session keys for Alice are added to keystore.
bob: boolShortcut for --name Bob --validator.
Session keys for Bob are added to keystore.
charlie: boolShortcut for --name Charlie --validator.
Session keys for Charlie are added to keystore.
dave: boolShortcut for --name Dave --validator.
Session keys for Dave are added to keystore.
eve: boolShortcut for --name Eve --validator.
Session keys for Eve are added to keystore.
ferdie: boolShortcut for --name Ferdie --validator.
Session keys for Ferdie are added to keystore.
one: boolShortcut for --name One --validator.
Session keys for One are added to keystore.
two: boolShortcut for --name Two --validator.
Session keys for Two are added to keystore.
Enable authoring even when offline.
tmp: boolRun a temporary node.
A temporary directory will be created to store the configuration and will be deleted at the end of the process.
Note: the directory is random per process execution. This directory is used as base path which includes: database, node key and keystore.
When --dev is given and no explicit --base-path, this option is implied.
Implementations
Sourceimpl RunCmd
impl RunCmd
Sourcepub fn get_keyring(&self) -> Option<Sr25519Keyring>
pub fn get_keyring(&self) -> Option<Sr25519Keyring>
Get the Sr25519Keyring matching one of the flag.